MethodChannelEsimToolkit class

An implementation of EsimToolkitPlatform that uses method channels.

Inheritance

Constructors

MethodChannelEsimToolkit()

Properties

eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
onEvent → Stream
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

installEsimProfile(String profile) → Future<String>
override
instructions() → Future<String>
override
isSupportESim(List<String>? newer) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited